@@ -4,7 +4,11 @@
 // Defines determined during configuration of m4ri.
 #define __M4RI_HAVE_MM_MALLOC		1
 #define __M4RI_HAVE_POSIX_MEMALIGN	1
-#define __M4RI_HAVE_SSE2		(defined(__SSE2__) && __SSE2__)
+#define __M4RI_HAVE_SSE2		0
+#if 1 && defined(__SSE2__) && __SSE2__
+#undef __M4RI_HAVE_SSE2
+#define __M4RI_HAVE_SSE2		1
+#endif
 #define __M4RI_HAVE_OPENMP		1
 #define __M4RI_CPU_L1_CACHE		32768
 #define __M4RI_CPU_L2_CACHE		1048576
@@ -14,7 +18,7 @@
 #define __M4RI_HAVE_LIBPNG              1
 
 #define __M4RI_CC                       "gcc"
-#define __M4RI_CFLAGS                   "-fopenmp -march=x86-64-v2 -O3 -pipe -fno-plt -fexceptions -Wp,-D_FORTIFY_SOURCE=3 -Wformat -Werror=format-security -fstack-clash-protection -fcf-protection -fno-omit-frame-pointer -mno-omit-leaf-frame-pointer -mpclmul -g -ffile-prefix-map=/startdir/src=/usr/src/debug/m4ri -flto=auto -falign-functions=32"
+#define __M4RI_CFLAGS                   "-fopenmp -march=x86-64-v4 -O3 -pipe -fno-plt -fexceptions -Wp,-D_FORTIFY_SOURCE=3 -Wformat -Werror=format-security -fstack-clash-protection -fcf-protection -fno-omit-frame-pointer -mno-omit-leaf-frame-pointer -mpclmul -g -ffile-prefix-map=/startdir/src=/usr/src/debug/m4ri -flto=auto -falign-functions=32"
 #define __M4RI_OPENMP_CFLAGS            "-fopenmp"
 
 // Helper macros.
@@ -25,4 +29,9 @@
 #define __M4RI_ENABLE_MZD_CACHE         0
 #define __M4RI_ENABLE_MMC               0
 
+#if defined(__MINGW32__) || defined(__MINGW64__)
+#define random rand
+#define srandom srand
+#endif
+
 #endif // M4RI_M4RI_CONFIG_H
